.. _contribmodel:

Modelling
=========

Sharing research and findings that used Arbor is the best contribution you can make to the project.
We encourage the use of our GitHub Discussions board and Gitter for public discussions on modelling.

We try to collect models scientists have built in our `contributor space <https://github.com/arbor-sim/contrib>`_.
In addition to the tutorials, browsing these models should give you a good idea of what's possible with Arbor
and find get in contact with other Arbor users.

We're always happy to hear about Arbor being used! Have you used Arbor to create a model?
Have you used Arbor in a publication? Do you have a workflow or tool that involves Arbor?
Get in touch and we'd be very happy to showcase your work through our channels.
